==> haskell-resourcet-1.2.4.2-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 resourcet
version:              1.2.4.2
visibility:           public
id:                   resourcet-1.2.4.2-8VlJo6yN26lBlamTMjWrHN
key:                  resourcet-1.2.4.2-8VlJo6yN26lBlamTMjWrHN
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.

category:             Data, Conduit
abi:                  903cb278259b228bd2cb476263d1eb43
exposed:              True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource

import-dirs:          /usr/lib/ghc-8.10.4/site-local/resourcet-1.2.4.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/resourcet-1.2.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/resourcet-1.2.4.2
hs-libraries:         HSresourcet-1.2.4.2-8VlJo6yN26lBlamTMjWrHN
depends:
    base-4.14.1.0 containers-0.6.2.1 exceptions-0.10.4 mtl-2.2.2
    primitive-0.7.1.0-4basvdNEktJ1IOTknZqeFm transformers-0.5.6.2
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:   /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html:         /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resourcet-1.2.4.2-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 resourcet
version:              1.2.4.2
visibility:           public
id:                   resourcet-1.2.4.2-HAfwAGu4bbRDn6PUO3bzf2
key:                  resourcet-1.2.4.2-HAfwAGu4bbRDn6PUO3bzf2
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.

category:             Data, Conduit
abi:                  53de32f548439da034fdd7489eef0a5e
exposed:              True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource

import-dirs:          /usr/lib/ghc-8.10.4/site-local/resourcet-1.2.4.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/resourcet-1.2.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/resourcet-1.2.4.2
hs-libraries:         HSresourcet-1.2.4.2-HAfwAGu4bbRDn6PUO3bzf2
depends:
    base-4.14.1.0 containers-0.6.2.1 exceptions-0.10.4 mtl-2.2.2
    primitive-0.7.1.0-E4X9CCBanM6KFkbtZATozp transformers-0.5.6.2
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:   /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html:         /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
